"""
Define various message strings generated in the code
"""

__author__      = "Graham Klyne (GK@ACM.ORG)"
__copyright__   = "Copyright 2014, G. Klyne"
__license__     = "MIT (http://opensource.org/licenses/MIT)"

import logging
log = logging.getLogger(__name__)

SITE_NAME_DEFAULT       = "Annalist linked data notebook"
ACTION_COMPLETED        = "Action completed"
NO_ACTION_PERFORMED     = "No action performed"
INPUT_ERROR             = "Problem with input"
SYSTEM_ERROR            = "System error"
UNEXPECTED_FORM_DATA    = "Unexpected form data: %r"
MISSING_COLLECTION_ID   = "Missing identifier for new collection"
INVALID_COLLECTION_ID   = "Invalid identifier for new collection: '%(coll_id)s'"
CREATED_COLLECTION_ID   = "Created new collection: '%(coll_id)s'"
REMOVE_COLLECTIONS      = "Remove collection(s): %(ids)s"
NO_COLLECTIONS_SELECTED = "No collections selected for removal"
COLLECTIONS_REMOVED     = "The following collections were removed: %(ids)s"
NO_TYPE_FOR_COPY        = "No record type selected to copy"
NO_TYPE_FOR_EDIT        = "No record type selected to edit"
NO_TYPE_FOR_DELETE      = "No record type selected to delete"
NO_VIEW_FOR_COPY        = "No record view selected to copy"
NO_VIEW_FOR_EDIT        = "No record view selected to edit"
NO_VIEW_FOR_DELETE      = "No record view selected to delete"
NO_LIST_FOR_COPY        = "No list view selected to copy"
NO_LIST_FOR_EDIT        = "No list view selected to edit"
NO_LIST_FOR_DELETE      = "No list view selected to delete"
DOES_NOT_EXIST          = "%(id)s does not exist"
REMOVE_RECORD_TYPE      = "Remove record type %(id)s in collection %(coll_id)s"
REMOVE_RECORD_LIST      = "Remove record list %(id)s in collection %(coll_id)s"
REMOVE_RECORD_VIEW      = "Remove record view %(id)s in collection %(coll_id)s"
COLLECTION_ID           = "Problem with collection identifier"
COLLECTION_ID_INVALID   = "The collection identifier is missing or not a valid identifier"
COLLECTION_LABEL        = "Collection %(id)s"
COLLECTION_EXISTS       = "Collection %(id)s already exists"
COLLECTION_NOT_EXISTS   = "Collection %(id)s does not exist"
RECORD_TYPE_ID          = "Problem with record type identifier"
RECORD_TYPE_ID_INVALID  = "The record type identifier is missing or not a valid identifier"
RECORD_TYPE_LABEL       = "Record type %(id)s in collection %(coll_id)s"
RECORD_TYPE_EXISTS      = "Record type %(id)s in collection %(coll_id)s already exists"
RECORD_TYPE_NOT_EXISTS  = "Record type %(id)s in collection %(coll_id)s does not exist"
RECORD_TYPE_REMOVED     = "Record type %(id)s in collection %(coll_id)s was removed"
RECORD_VIEW_ID          = "Problem with record view identifier"
RECORD_VIEW_ID_INVALID  = "The record view identifier is missing or not a valid identifier"
RECORD_VIEW_LABEL       = "Record view %(id)s in collection %(coll_id)s"
RECORD_VIEW_EXISTS      = "Record view %(id)s in collection %(coll_id)s already exists"
RECORD_VIEW_NOT_EXISTS  = "Record view %(id)s in collection %(coll_id)s does not exist"
RECORD_VIEW_REMOVED     = "Record view %(id)s in collection %(coll_id)s was removed"
RECORD_LIST_ID          = "Problem with record list identifier"
RECORD_LIST_ID_INVALID  = "The record list identifier is missing or not a valid identifier"
RECORD_LIST_LABEL       = "Record list %(id)s in collection %(coll_id)s"
RECORD_LIST_EXISTS      = "Record list %(id)s in collection %(coll_id)s already exists"
RECORD_LIST_NOT_EXISTS  = "Record list %(id)s in collection %(coll_id)s does not exist"
RECORD_LIST_REMOVED     = "Record list %(id)s in collection %(coll_id)s was removed"
RECORD_FIELD_ID         = "Problem with record field identifier"
RECORD_FIELD_ID_INVALID = "The record field identifier is missing or not a valid identifier"
RECORD_FIELD_LABEL      = "Record field %(id)s in collection %(coll_id)s"
RECORD_FIELD_EXISTS     = "Record field %(id)s in collection %(coll_id)s already exists"
RECORD_FIELD_NOT_EXISTS = "Record field %(id)s in collection %(coll_id)s does not exist"
RECORD_FIELD_REMOVED    = "Record field %(id)s in collection %(coll_id)s was removed"
RECORD_ENUM_ID          = "Problem with enumeration type identifier"
RECORD_ENUM_ID_INVALID  = "The enumeration type identifier is missing or not a valid identifier"
RECORD_ENUM_LABEL       = "Enumeration type %(id)s in collection %(coll_id)s"
RECORD_ENUM_EXISTS      = "Enumeration type %(id)s in collection %(coll_id)s already exists"
RECORD_ENUM_NOT_EXISTS  = "Enumeration type %(id)s in collection %(coll_id)s does not exist"
RECORD_ENUM_REMOVED     = "Enumeration type %(id)s in collection %(coll_id)s was removed"
TOO_MANY_ENTITIES_SEL   = "Too many items selected"
NO_ENTITY_FOR_COPY      = "No data record selected to copy"
NO_ENTITY_FOR_EDIT      = "No data record selected to edit"
NO_ENTITY_FOR_DELETE    = "No data record selected to delete"
SITE_ENTITY_FOR_DELETE  = "Cannot remove site built-in entity %(id)s"
REMOVE_ENTITY_DATA      = "Remove record %(id)s of type %(type_id)s in collection %(coll_id)s"
ENTITY_DATA_ID          = "Problem with entity identifier"
ENTITY_DATA_ID_INVALID  = "The entity identifier is missing or not a valid identifier"
ENTITY_DATA_LABEL       = "Entity %(id)s of type %(type_id)s in collection %(coll_id)s"
ENTITY_DATA_EXISTS      = "Entity %(id)s of type %(type_id)s in collection %(coll_id)s already exists"
ENTITY_DATA_NOT_EXISTS  = "Entity %(id)s of type %(type_id)s in collection %(coll_id)s does not exist"
ENTITY_DATA_REMOVED     = "Entity %(id)s of type %(type_id)s in collection %(coll_id)s was removed"
ENTITY_TYPE_ID          = "Problem with entity type identifier"
ENTITY_TYPE_ID_INVALID  = "The entity type identifier is missing or not a valid identifier"
DEFAULT_VIEW_UPDATED    = "Default list view for collection %(coll_id)s changed to %(list_id)s"
REMOVE_FIELD_ERROR      = "Problem with remove field(s) request"
NO_FIELD_SELECTED       = "No field(s) selected"
ENTITY_MESSAGE_LABEL    = "Entity %(type_id)s/%(entity_id)s in collection %(coll_id)s"
ENTITY_DEFAULT_LABEL    = ""    # "Entity %(type_id)s/%(entity_id)s in collection %(coll_id)s"
ENTITY_DEFAULT_COMMENT  = ""    # "Entity %(type_id)s/%(entity_id)s in collection %(coll_id)s"

# End.
